//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Support/IO/IDataLoader.cpp
//! @brief     Implements class IDataLoader
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Support/IO/IDataLoader.h"
#include <QString>

void IDataLoader::populateImportSettingsWidget(QWidget*) {}

void IDataLoader::applyImportSettings() {}

void IDataLoader::initWithDefaultImportSettings() {}

QByteArray IDataLoader::serialize() const
{
    return QByteArray();
}

void IDataLoader::deserialize(const QByteArray&) {}

QByteArray IDataLoader::defaultImportSettings() const
{
    std::unique_ptr<IDataLoader> cloned(clone());
    cloned->initWithDefaultImportSettings();
    return cloned->serialize();
}

void IDataLoader::guessSettings() {}

int IDataLoader::numErrors() const
{
    return 0;
}

int IDataLoader::numLineRelatedErrors() const
{
    return 0;
}

QStringList IDataLoader::lineUnrelatedErrors() const
{
    return {};
}

IDataLoaderResultModel* IDataLoader::createResultModel() const
{
    return nullptr;
}

QByteArray IDataLoader::fileContent() const
{
    return {};
}

void IDataLoader::setRealDataItem(RealItem* item)
{
    m_item = item;
}

RealItem* IDataLoader::realItem()
{
    return m_item;
}

const RealItem* IDataLoader::realItem() const
{
    return m_item;
}

QDataStream& operator<<(QDataStream& stream, const IDataLoader& s)
{
    stream << s.serialize();
    return stream;
}

QDataStream& operator>>(QDataStream& stream, IDataLoader& s)
{
    QByteArray b;
    stream >> b;
    s.deserialize(b);
    return stream;
}
